Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EtcdBackupExpansion ¶
type EtcdBackupExpansion interface{}
type EtcdBackupInterface ¶
type EtcdBackupInterface interface {
Create(*v1beta2.EtcdBackup) (*v1beta2.EtcdBackup, error)
Update(*v1beta2.EtcdBackup) (*v1beta2.EtcdBackup, error)
UpdateStatus(*v1beta2.EtcdBackup) (*v1beta2.EtcdBackup, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta2.EtcdBackup, error)
List(opts v1.ListOptions) (*v1beta2.EtcdBackupList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta2.EtcdBackup, err error)
EtcdBackupExpansion
}
EtcdBackupInterface has methods to work with EtcdBackup resources.
type EtcdBackupsGetter ¶
type EtcdBackupsGetter interface {
EtcdBackups(namespace string) EtcdBackupInterface
}
EtcdBackupsGetter has a method to return a EtcdBackupInterface. A group's client should implement this interface.
type EtcdClusterExpansion ¶
type EtcdClusterExpansion interface{}
type EtcdClusterInterface ¶
type EtcdClusterInterface interface {
Create(*v1beta2.EtcdCluster) (*v1beta2.EtcdCluster, error)
Update(*v1beta2.EtcdCluster) (*v1beta2.EtcdCluster, error)
UpdateStatus(*v1beta2.EtcdCluster) (*v1beta2.EtcdCluster, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta2.EtcdCluster, error)
List(opts v1.ListOptions) (*v1beta2.EtcdClusterList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta2.EtcdCluster, err error)
EtcdClusterExpansion
}
EtcdClusterInterface has methods to work with EtcdCluster resources.
type EtcdClustersGetter ¶
type EtcdClustersGetter interface {
EtcdClusters(namespace string) EtcdClusterInterface
}
EtcdClustersGetter has a method to return a EtcdClusterInterface. A group's client should implement this interface.
type EtcdRestoreExpansion ¶
type EtcdRestoreExpansion interface{}
type EtcdRestoreInterface ¶
type EtcdRestoreInterface interface {
Create(*v1beta2.EtcdRestore) (*v1beta2.EtcdRestore, error)
Update(*v1beta2.EtcdRestore) (*v1beta2.EtcdRestore, error)
UpdateStatus(*v1beta2.EtcdRestore) (*v1beta2.EtcdRestore, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta2.EtcdRestore, error)
List(opts v1.ListOptions) (*v1beta2.EtcdRestoreList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta2.EtcdRestore, err error)
EtcdRestoreExpansion
}
EtcdRestoreInterface has methods to work with EtcdRestore resources.
type EtcdRestoresGetter ¶
type EtcdRestoresGetter interface {
EtcdRestores(namespace string) EtcdRestoreInterface
}
EtcdRestoresGetter has a method to return a EtcdRestoreInterface. A group's client should implement this interface.
type EtcdV1beta2Client ¶
type EtcdV1beta2Client struct {
// contains filtered or unexported fields
}
EtcdV1beta2Client is used to interact with features provided by the etcd.database.coreos.com group.
func New ¶
func New(c rest.Interface) *EtcdV1beta2Client
New creates a new EtcdV1beta2Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*EtcdV1beta2Client, error)
NewForConfig creates a new EtcdV1beta2Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *EtcdV1beta2Client
NewForConfigOrDie creates a new EtcdV1beta2Client for the given config and panics if there is an error in the config.
func (*EtcdV1beta2Client) EtcdBackups ¶
func (c *EtcdV1beta2Client) EtcdBackups(namespace string) EtcdBackupInterface
func (*EtcdV1beta2Client) EtcdClusters ¶
func (c *EtcdV1beta2Client) EtcdClusters(namespace string) EtcdClusterInterface
func (*EtcdV1beta2Client) EtcdRestores ¶
func (c *EtcdV1beta2Client) EtcdRestores(namespace string) EtcdRestoreInterface
func (*EtcdV1beta2Client) RESTClient ¶
func (c *EtcdV1beta2Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type EtcdV1beta2Interface ¶
type EtcdV1beta2Interface interface {
RESTClient() rest.Interface
EtcdBackupsGetter
EtcdClustersGetter
EtcdRestoresGetter
}